Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(808)

Unified Diff: net/proxy/proxy_config.h

Issue 710623002: Merge to M39: Correct manual proxy selection for WebSockets. (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@2171
Patch Set: Created 6 years, 1 month ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « no previous file | net/proxy/proxy_config.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: net/proxy/proxy_config.h
diff --git a/net/proxy/proxy_config.h b/net/proxy/proxy_config.h
index e558174a4658bc558afaa331035b766548274e92..90ac96be83ab491a71820af33aa20d157d69cc6d 100644
--- a/net/proxy/proxy_config.h
+++ b/net/proxy/proxy_config.h
@@ -138,9 +138,15 @@ class NET_EXPORT ProxyConfig {
private:
// Returns one of {&proxies_for_http, &proxies_for_https, &proxies_for_ftp}
// or NULL if it is a scheme that we don't have a mapping
// for. Should only call this if the type is TYPE_PROXY_PER_SCHEME.
ProxyList* MapUrlSchemeToProxyListNoFallback(const std::string& scheme);
+
+ // Returns the first of {&fallback_proxies, &proxies_for_https,
+ // &proxies_for_http} that is non-empty, or NULL.
+ const ProxyList* GetProxyListForWebSocketScheme() const;
};
typedef int ID;
« no previous file with comments | « no previous file | net/proxy/proxy_config.cc » ('j') | no next file with comments »
@@ -138,9 +138,15 @@ class NET_EXPORT ProxyConfig {
private:
// Returns one of {&proxies_for_http, &proxies_for_https, &proxies_for_ftp}
- // or NULL if it is a scheme that we don't have a mapping
- // for. Should only call this if the type is TYPE_PROXY_PER_SCHEME.
+ // or NULL if it is a scheme that we don't have a mapping for. Should only
+ // call this if the type is TYPE_PROXY_PER_SCHEME. Intentionally returns
+ // NULL for "ws" and "wss" as those are handled specially by
+ // GetProxyListForWebSocketScheme().
ProxyList* MapUrlSchemeToProxyListNoFallback(const std::string& scheme);

Powered by Google App Engine
This is Rietveld 408576698